#
# ovirt-hosted-engine-setup -- ovirt hosted engine setup
# Copyright (C) 2013-2017 Red Hat, Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#

%global commit 63401ae18e756220f6d01bc71bb06da09920530d
%global shortcommit %(c=%{commit}; echo ${c:0:7})
%define enable_autotools 1

%global         package_version 2.2.24
%global         ovirt_hosted_engine_setup_templates %{_datadir}/%{name}/templates
%global         ovirt_hosted_engine_setup_scripts %{_datadir}/%{name}/scripts
%global         vdsmhooksdir %{_libexecdir}/vdsm/hooks


Summary:        oVirt Hosted Engine setup tool
Name:           ovirt-hosted-engine-setup
Version:        2.2.24
Release:        1%{?release_suffix}%{?dist}
License:        LGPLv2+
URL:            http://www.ovirt.org
Source0:        http://resources.ovirt.org/pub/src/%{name}/%{name}-%{package_version}.tar.gz
Source1:        readme.appliance
Source2:        readme.rollback
Group:          Applications/System

BuildArch:      noarch

Requires:       bind-utils
Requires:       genisoimage
Requires:       iptables
Requires:       iptables-services
Requires:       libselinux-python
Requires:       lsof
Requires:       openssh-server
Requires:       openssl
Requires:       pyliblzma
Requires:       python
Requires:       python-ethtool >= 0.6-3
Requires:       python-netaddr
Requires:       python-libguestfs
Requires:       python-six
Requires:       sanlock >= 2.8
Requires:       sanlock-python >= 2.8
Requires:       socat
Requires:       sudo
Requires:       libvirt-client
Requires:       m2crypto
Requires:       virt-install
Requires:       python-ovirt-engine-sdk4 >= 4.2.4
Requires:       ansible >= 2.5.2
# default libvirt network
Requires:       libvirt-daemon-config-network

BuildRequires:  gettext >= 0.18.2
BuildRequires:  python2-devel
BuildRequires:  pytest

%if 0%{?enable_autotools}
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gettext-devel
%endif

%if 0%{?fedora}
Requires:       qemu-img
%endif

%if 0%{?rhel}
Requires:       qemu-img-rhev
%endif


Requires:       otopi >= 1.7.3
Requires:       ovirt-host-deploy >= 1.7.0
Requires:       ovirt-hosted-engine-ha >= 2.2.13
Requires:       ovirt-engine-sdk-python >= 3.6.9.1
Requires:       ovirt-setup-lib >= 1.1.3
# RHGS still missing 3.12.0
Requires:       glusterfs-cli >= 3.8.0
Requires:       vdsm-python >= 4.20.21
Requires(post): vdsm-python >= 4.20.21
Requires:       ovirt-host >= 4.2.2

Conflicts:      rhevm-appliance < 1:4.0
Conflicts:      rhvm-appliance < 2:4.2
Conflicts:      rhvm-appliance >= 2:4.3

Patch1: 0001-packaging-branding-for-ovirt-hosted-engine-setup.patch

%description
Hosted Engine setup tool for oVirt project.

%prep
%setup -q -n %{name}-%{package_version}
%patch1 -p1
cp %{SOURCE1} %{SOURCE2} .

%build
%if 0%{?enable_autotools}
autoreconf -ivf
%endif
%configure \
        --docdir="%{_docdir}/%{name}-%{version}" \
        --disable-python-syntax-check \
        %{?conf}
make %{?_smp_mflags}

%check
make test

%install
make %{?_smp_mflags} install DESTDIR="%{buildroot}"
%find_lang %{name}

%files -f %{name}.lang
%license COPYING
%doc README
%doc readme.appliance
%doc readme.rollback
%dir %{_sysconfdir}/ovirt-hosted-engine-setup.env.d
%dir %{_sysconfdir}/ovirt-hosted-engine
%ghost %attr(600, root, root) %{_sysconfdir}/ovirt-hosted-engine/virsh_auth.conf
%dir %attr(700, root, root) %{_localstatedir}/log/ovirt-hosted-engine-setup
%dir %{_localstatedir}/lib/ovirt-hosted-engine-setup
%dir %{_localstatedir}/lib/ovirt-hosted-engine-setup/answers
%{_sbindir}/hosted-engine
%{_sbindir}/ovirt-hosted-engine-setup
%{_sbindir}/ovirt-hosted-engine-cleanup
%{python_sitelib}/ovirt_hosted_engine_setup/
%{_datadir}/%{name}/
%{_mandir}/man8/*

#move to a separate package?
%{vdsmhooksdir}/before_vm_start/

%post
touch %{_sysconfdir}/ovirt-hosted-engine/virsh_auth.conf
chmod 600 %{_sysconfdir}/ovirt-hosted-engine/virsh_auth.conf
python -c '
from vdsm.tool.configurators import passwd
print((
    "[credentials-vdsm]\n"
    "authname={authname}\n"
    "password={password}\n\n"
    "[auth-libvirt-localhost]\n"
    "credentials=vdsm\n"
).format(
    authname=passwd.SASL_USERNAME,
    password=passwd.libvirt_password(),
))
' > %{_sysconfdir}/ovirt-hosted-engine/virsh_auth.conf

%changelog
* Thu Jul 19 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.24-1
- 2.2.24-1
- Rebase on upstream 2.2.24
- Resolves: BZ#1596330
- Resolves: BZ#1193961
- Resolves: BZ#1590943
- Resolves: BZ#1601790

* Fri Jun 29 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.23-1
- 2.2.23-1
- Rebase on upstream 2.2.23
- Resolves: BZ#1596330
- Resolves: BZ#1573461
- Resolves: BZ#1588720
- Resolves: BZ#1590266
- Resolves: BZ#1574336
- Resolves: BZ#1578144

* Mon Jun 25 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.22.1-1
- 2.2.22.1-1
- Rebase on upstream 2.2.22.1
- Resolves: BZ#1594893
- Resolves: BZ#1594024

* Wed May 30 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.22-1
- Rebase on upstream 2.2.22
- Resolves: BZ#1581783
- Resolves: BZ#1557793
- Resolves: BZ#1576310

* Wed May 23 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.21-1
- Rebase on upstream 2.2.21
- Resolves: BZ#1581783
- Resolves: BZ#1572542
- Resolves: BZ#1578418
- Resolves: BZ#1557775
- Resolves: BZ#1578404
- Resolves: BZ#1573074
- Resolves: BZ#1576451

* Wed May  2 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.20-1
- Rebase on upstream 2.2.20
- Resolves: BZ#1458709
- Resolves: BZ#1571113
- Resolves: BZ#1571467

* Tue Apr 24 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.19-1
- Rebase on upstream 2.2.19
- Resolves: BZ#1458709
- Resolves: BZ#1466132
- Resolves: BZ#1565730
- Resolves: BZ#1560610

* Tue Apr 17 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.18-1
- Rebase on upstream 2.2.18
- Resolves: BZ#1458709
- Resolves: BZ#1567772
- Resolves: BZ#1538934

* Tue Apr 10 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.17-1
- Rebase on upstream 2.2.17
- Resolves: BZ#1458709
- Resolves: BZ#1565060

* Thu Apr  5 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.16-1
- Rebase on upstream 2.2.16
- Resolves: BZ#1458709
- Resolves: BZ#1522737
- Resolves: BZ#1563664
- Resolves: BZ#1562349
- Resolves: BZ#1560655
- Resolves: BZ#1560551

* Mon Mar 26 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.15-1
- Rebase on upstream 2.2.15
- Resolves: BZ#1458709
- Resolves: BZ#1522737
- Resolves: BZ#1559534
- Resolves: BZ#1559750
- Resolves: BZ#1469143

* Wed Mar 21 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.14-1
- Rebase on upstream 2.2.14
- Resolves: BZ#1458709
- Resolves: BZ#1479714
- Resolves: BZ#1540150
- Resolves: BZ#1558546
- Resolves: BZ#1558568

* Wed Mar 14 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.13-1
- Rebase on upstream 2.2.13
- Resolves: BZ#1458709
- Resolves: BZ#1420115
- Resolves: BZ#1528813
- Resolves: BZ#1543486
- Resolves: BZ#1547595

* Thu Mar 01 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.12-1
- Rebase on upstream 2.2.12
- Resolves: BZ#1458709
- Resolves: BZ#1540150
- Resolves: BZ#1546652
- Resolves: BZ#1533500
- Resolves: BZ#1543218
- Resolves: BZ#1548508
- Resolves: BZ#1546764
- Resolves: BZ#1543486
- Resolves: BZ#1543486

* Tue Feb 20 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.11-1
- Rebase on upstream 2.2.11
- Resolves: BZ#1458709
- Resolves: BZ#1540107
- Resolves: BZ#1545931
- Resolves: BZ#1540463
- Resolves: BZ#1534212

* Wed Feb 14 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.10-1
- Rebase on upstream 2.2.10
- Resolves: BZ#1458709
- Resolves: BZ#1542604
- Resolves: BZ#1541328
- Resolves: BZ#1541412
- Resolves: BZ#1543424

* Thu Feb 01 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.9-1
- Rebase on upstream 2.2.9
- Resolves: BZ#1458709
- Resolves: BZ#1540850
- Resolves: BZ#1539734
- Resolves: BZ#1537588
- Resolves: BZ#1540150

* Fri Jan 26 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.8-2
- Rebase on upstream 2.2.8
- Resolves: BZ#1458709
- Resolves: BZ#1537630

* Wed Jan 24 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.8-1
- Rebase on upstream 2.2.8
- Resolves: BZ#1458709
- Resolves: BZ#1537630

* Tue Jan 23 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.7-1
- Rebase on upstream 2.2.7
- Resolves: BZ#1458709
- Resolves: BZ#1537153
- Resolves: BZ#1507427
- Resolves: BZ#1536941
- Resolves: BZ#1536055

* Wed Jan 10 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.6-1
- Rebase on upstream 2.2.6
- Resolves: BZ#1458709
- Resolves: BZ#1534432
- Resolves: BZ#1530209
- Resolves: BZ#1526753
- Resolves: BZ#1426517
- Resolves: BZ#1353713

* Wed Jan 10 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.5-1
- Rebase on upstream 2.2.5
- Resolves: BZ#1458709
- Resolves: BZ#1529490
- Resolves: BZ#1530125
- Resolves: BZ#1529941
- Resolves: BZ#1532213
- Resolves: BZ#1529131
- Resolves: BZ#1526752

* Fri Dec 22 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.2.3-1
- Rebase on upstream 2.2.3
- Resolves: BZ#1458709
- Resolves: BZ#1527335
- Resolves: BZ#1527135
- Resolves: BZ#1525955

* Thu Dec 14 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.2.2-1
- Rebase on upstream 2.2.2
- Resolves: BZ#1458709
- Resolves: BZ#1525854

* Mon Dec 11 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.2.1-1
- Rebase on upstream 2.2.1
- Resolves: BZ#1458709
- Resolves: BZ#1522712

* Thu Nov 30 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.2.0-2
- Rebase on upstream 2.2.0
- Fix RPM release info
- Resolves: BZ#1458709

* Thu Nov 30 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.2.0-1
- Rebase on upstream 2.2.0
- Resolves: BZ#1458709
- Resolves: BZ#1461251
- Resolves: BZ#1434209
- Resolves: BZ#1481680
- Resolves: BZ#1267807
- Resolves: BZ#1466234
- Resolves: BZ#1400890
- Resolves: BZ#1449557
- Resolves: BZ#1449565
- Resolves: BZ#1487560
- Resolves: BZ#1464461

* Wed Nov 15 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.2.0-0.4
- Developement build

* Wed Aug  9 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.3.6-1
- 2.1.3.6-1
- Resolves: BZ#1479856

* Thu Jul 27 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.3.5-1
- 2.1.3.5-1
- Resolves: BZ#1467813

* Wed Jul 05 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.3.4-1
- Rebase on upstream 2.1.3.4
- Resolves: BZ#1467934

* Wed Jul 05 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.3.3-1
- Rebase on upstream 2.1.3.3
- Resolves: BZ#1455606

* Mon Jun 26 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 2.1.3.2-1
- Rebase on upstream 2.1.3.2
- Resolves: BZ#1464866

* Wed Jun 14 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 2.1.3.1-1
- Rebase on upstream 2.1.3.1
- Resolves: BZ#1455606

* Wed Jun  7 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 2.1.3-1
- Rebase on upstream 2.1.3
- Resolves: BZ#1426898
- Resolves: BZ#1459229

* Thu Jun  1 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.2-2
- 2.1.2-2
- Resolves: BZ#1455606
- Resolves: BZ#1457684

* Wed May 31 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.2-1
- 2.1.2-1
- Resolves: BZ#1455606

* Thu May 25 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.1-1
- 2.1.1-1
- Resolves: BZ#1455606

* Fri Apr 21 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.0.6-1
- 2.1.0.6-1

* Wed Mar 22 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.0.5-1
- 2.1.0.5-1
- Resolves: BZ#1379405

* Thu Mar  2 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.0.4-1
- 2.1.0.4-1
- Resolves: BZ#1379405

* Wed Feb 15 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.0.3-1
- 2.1.0.3-1
- Resolves: BZ#1379405

* Thu Feb 09 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.0.2-1
- 2.1.0.2-1
- Resolves: BZ#1379405

* Thu Jan 26 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.0.1-1
- 2.1.0.1-1
- Resolves: BZ#1379405
- Resolves: BZ#1416023
- Resolves: BZ#1409203

* Tue Jan 17 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.0-2
- 2.1.0-2
- Resolves: BZ#1379405

* Fri Jan 13 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.0-1
- 2.1.0-1
- Resolves: BZ#1379405

* Wed Sep 28 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.0.3-1
- 2.0.3-1
- Resolves: BZ#1373484
- Resolves: BZ#1377778
- Resolves: BZ#1378111
- Resolves: BZ#1347340
- Resolves: BZ#1343451

* Wed Sep 14 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.0.2.2-2
- 2.0.2.2-2
- Resolves: BZ#1371590
- Resolves: BZ#1375188

* Wed Sep 14 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.0.2.2-1
- 2.0.2.2-1
- Resolves: BZ#1371590

* Wed Sep 07 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.0.2.1-1
- 2.0.2.1-1
- Resolves: BZ#1371590

* Tue Aug 30 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.0.2-1
- 2.0.2-1
- Resolves: BZ#1371590

* Thu Aug 25 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.0.1.5-1
- 2.0.1.5-1
- Resolves: BZ#1369712

* Tue Aug 09 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.0.1.4-1
- 2.0.1.4-1
- Resolves: BZ#1364615
- Resolves: BZ#1335952
- Resolves: BZ#1358255

* Wed Jul 27 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.0.1.3-1
- 2.0.1.3-1
- Resolves: BZ#1313917

* Tue Jul 26 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.0.1.2-1
- 2.0.1.2-1
- Resolves: BZ#1313917

* Wed Jul 20 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.0.1.1-1
- 2.0.1.1-1
- Resolves: BZ#1356221

* Tue Jul 12 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 2.0.1-1
- 2.0.1-1
- Resolves: BZ#1319457
- Resolves: BZ#1335426
- Resolves: BZ#1352160
- Resolves: BZ#1352601
- Resolves: BZ#1353537

* Thu Jun 16 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.0.0.2-1
- 2.0.0.2-1
- Resolves: BZ#1306965

* Wed Jun 08 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.0.0.1-1
- 2.0.0.1-1
- Resolves: BZ#1306965

* Tue May 31 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 2.0.0-1
- 2.0.0-1
- Resolves: BZ#1293654
- Resolves: BZ#1306965

* Tue Dec 22 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.2-1
- Rebase on upstream 1.3.2
- Resolves: BZ#1293654

* Tue Dec 15 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.1.3-1
- Rebase on upstream 1.3.1.3
- Resolves: BZ#1284979

* Wed Dec  9 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.1.2-1
- Rebase on upstream 1.3.1.2
- Resolves: BZ#1284979

* Tue Dec  1 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.1.1-1
- Rebase on upstream 1.3.1.1
- Resolves: BZ#1284979

* Tue Nov 24 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.1-1
- Rebase on upstream 1.3.1
- Resolves: BZ#1254838
- Resolves: BZ#1059952

* Wed Nov 18 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.1-0.1.master.gitc013638
- Resolves: BZ#1254838
- Resolves: BZ#1059952
- Resolves oVirt bugs:
  - rhbz#1269430
  - rhbz#1273937
  - rhbz#1256467 (blocker+)
  - rhbz#1268373
  - rhbz#1271511
  - rhbz#1247068
  - rhbz#1269182
  - rhbz#1283141
  - rhbz#1278725

* Thu Sep 24 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.0-1
- Resolves: BZ#1234915

* Tue Sep 22 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.0-0.8.beta.git63c6aad
- Resolves: BZ#1247942
- Resolves: BZ#1255026
- Resolves: 1258465
- Resolves: 1263295

* Tue Sep 15 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.0-0.7.beta.gitc63047c
- Resolves: BZ#1234915
- Resolves: BZ#1262875

* Wed Sep  9 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.0-0.6.beta.git794400d
- Resolves: BZ#1251912
- Resolves: BZ#1254671
- Resolves: BZ#1253939
- Resolves: BZ#1234915

* Tue Sep  1 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.0-0.5.beta.git2cd8189
- Resolves: BZ#1215436
- Resolves: BZ#1254104

* Wed Aug 12 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.0-0.4.beta.git42eb801
- Fixed glusterfs-cli requirement for RHEV.

* Tue Aug 11 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.0-0.3.beta.git42eb801
- Resolves: BZ#1032069
- Resolves: BZ#1131918
- Resolves: BZ#1210763
- Resolves: BZ#1228576
- Resolves: BZ#1235591
- Resolves: BZ#1238709
- Resolves: BZ#1242344
- Resolves: BZ#1242448
- Resolves: BZ#1249118

* Mon Jul  6 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.0-0.2.master.git2499139
- Resolves: BZ#1236464

* Thu Jul  2 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.0-0.1.alpha
- Resolves: BZ#1077850
- Resolves: BZ#1108341
- Resolves: BZ#1120780
- Resolves: BZ#1139793
- Resolves: BZ#1175354
- Resolves: BZ#1188663
- Resolves: BZ#1205663
- Resolves: BZ#1211532
- Resolves: BZ#1213307
- Resolves: BZ#1216172
- Resolves: BZ#1217106
- Resolves: BZ#1220137
- Resolves: BZ#1221148
- Resolves: BZ#1222058
- Resolves: BZ#1223801
- Resolves: BZ#1225011
- Resolves: BZ#1234870

* Thu Apr 16 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.0-0.0.master.git9665976
- Resolves: BZ#1101553
- Resolves: BZ#1201196
- Resolves: BZ#1153278
- Resolves: BZ#1002454
- Resolves: BZ#1198138
- Resolves: BZ#1169290
- Resolves: BZ#1169792
- Resolves: BZ#1177800
- Resolves: BZ#1150073

